@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-07-04'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2015-07-27'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -428,10 +428,8 @@ sub _process_script {
         last unless $cli->read_env;
         #$self->log_debug(["skipped file %s (script does not read env)", $filename]);
         my @content;
-        push @content, "=over\n\n";
-        push @content, "=item * ", $cli->env_name, "\n\n";
+        push @content, "=head2 ", $cli->env_name, " => str\n\n";
         push @content, "Specify additional command-line options\n\n";
-        push @content, "=back\n\n";
 
         $self->add_text_to_section($document, join('', @content), 'ENVIRONMENT',
                                    {before_section=>'HOMEPAGE'});
@@ -596,7 +594,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.41 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-07-04.
+This document describes version 0.42 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
@@ -699,7 +697,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
 
 =head1 BUGS
 
